@@ -1,20 +1,8 @@
 /*
- *  Copyright (C) 2017 Marco Martin <mart@kde.org>
- *  Copyright (c) 2014 Vishesh Handa <me@vhanda.in>
+ *  SPDX-FileCopyrightText: 2017 Marco Martin <mart@kde.org>
+ *  SPDX-FileCopyrightText: 2014 Vishesh Handa <me@vhanda.in>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -41,7 +29,6 @@
 #include <kauthaction.h>
 #include <kauthexecutejob.h>
 
-#include <KNewStuff3/KNSCore/Engine>
 #include <KNewStuff3/KNSCore/EntryInternal>
 
 #include <KIO/CopyJob>
@@ -73,7 +60,6 @@ KCMPlymouth::KCMPlymouth(QObject *parent, const QVariantList &args)
 
 KCMPlymouth::~KCMPlymouth()
 {
-    delete m_newStuffDialog.data();
 }
 
 void KCMPlymouth::reloadModel()
@@ -126,33 +112,20 @@ void KCMPlymouth::reloadModel()
     emit selectedPluginIndexChanged();
 }
 
-void KCMPlymouth::getNewStuff(QQuickItem *ctx)
+void KCMPlymouth::onChangedEntriesChanged(const QQmlListReference &changedEntries)
 {
-    if (!m_newStuffDialog) {
-        m_newStuffDialog = new KNS3::DownloadDialog(QLatin1String("plymouth.knsrc"));
-        m_newStuffDialog->setWindowTitle(i18n("Download New Boot Splash Screens"));
-        m_newStuffDialog->setWindowModality(Qt::WindowModal);
-        m_newStuffDialog->winId(); // so it creates the windowHandle();
-        connect(m_newStuffDialog.data(), &KNS3::DownloadDialog::accepted, this, &KCMPlymouth::reloadModel);
-        connect(m_newStuffDialog.data(), &KNS3::DownloadDialog::finished, m_newStuffDialog.data(), &KNS3::DownloadDialog::deleteLater);
-
-        connect(m_newStuffDialog->engine(), &KNSCore::Engine::signalEntryChanged, this, [=](const KNSCore::EntryInternal &entry) {
-            if (!entry.isValid() || entry.status() != KNS3::Entry::Installed) {
-                return;
-            }
-
+    static QStringList alreadyCopiedThumbnails;
+    for (int i = 0; i < changedEntries.count(); ++i) {
+        auto entry = qobject_cast<KNSCore::EntryWrapper *>(changedEntries.at(i))->entry();
+        if (entry.isValid() && entry.status() == KNS3::Entry::Installed && !alreadyCopiedThumbnails.contains(entry.uniqueId())) {
+            alreadyCopiedThumbnails.append(entry.uniqueId());
             KIO::file_copy(QUrl(entry.previewUrl(KNSCore::EntryInternal::PreviewBig1)),
                            QUrl::fromLocalFile(QString(entry.installedFiles().constFirst() + QStringLiteral(".png"))),
                            -1,
                            KIO::Overwrite | KIO::HideProgressInfo);
-        });
+        }
     }
-
-    if (ctx && ctx->window()) {
-        m_newStuffDialog->windowHandle()->setTransientParent(ctx->window());
-    }
-
-    m_newStuffDialog->show();
+    reloadModel();
 }
 
 QStandardItemModel *KCMPlymouth::themesModel()
